# @anywidget/deno

## 0.1.2

### Patch Changes

- Prefer interface over type for WidgetOptions ([#498](https://github.com/manzt/anywidget/pull/498))

## 0.1.1

### Patch Changes

- Publish package to [`jsr:@anywidget/deno`](https://jsr.io/@anywidget/deno) ([#491](https://github.com/manzt/anywidget/pull/491))

  Deprecates https://deno.land/x/anywidget distribution for the preferred
  [JSR](https://jsr.io).

## 0.1.0

### Minor Changes

- Switch to sync API to define widget ([#487](https://github.com/manzt/anywidget/pull/487))

## 0.0.5

### Patch Changes

- feat: Allow Deno to check if display `in` widget
  ([`603b9e1`](https://github.com/manzt/anywidget/commit/603b9e1ab1cb1fa0aebcce37e8944a65853f0679))

## 0.0.4

### Patch Changes

- Bump anywidget version to 0.7.0
  ([`525e3c8`](https://github.com/manzt/anywidget/commit/525e3c8a6e9632bd7d4d1d4483d7381c32445428))

## 0.0.3

### Patch Changes

- feat: Try to discover installed anywidget version
  ([#326](https://github.com/manzt/anywidget/pull/326))

- feat: Add Install/Uninstall scripts for widget front end
  ([#329](https://github.com/manzt/anywidget/pull/329))

  ```sh
  deno run -A https://deno.land/x/anywidget/install.ts
  ```

## 0.0.2

### Patch Changes

- fix: Use current anywidget version in comms open message
  ([#323](https://github.com/manzt/anywidget/pull/323))

## 0.0.1

### Patch Changes

- feat: make initial release
  ([#319](https://github.com/manzt/anywidget/pull/319))
